/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.mcsla.core.metrics;

import eu.DECIDEh2020.appManager.models.Parameter;

import java.util.List;
import java.util.stream.Collectors;

class AvailabilityUptimeBillingCycle implements PredefinedExpression<Double, Long> {

    @Override
    public Double calculate(List<Long> input, List<Parameter> parameters) {
        Long totalDowntime = input.stream().reduce(0L, Long::sum);
        Double billingCycle = 2.592 * 625.92 * 60;

        for (Parameter p : parameters) {
            if (p.getId().contains("PARAM_BC") && p.getUnit().equals("second")) {
                billingCycle = Double.valueOf(p.getParameterStatement());
            }
        }

        double tmp = billingCycle - totalDowntime.doubleValue();
        return 100.0 - tmp/billingCycle;
    }

    @Override
    public Double calculateFromStrings(List<String> input, List<Parameter> parameters) {
        return calculate(input.stream().map(Long::valueOf).collect(Collectors.toList()), parameters);
    }

}
