/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.mcsla.core.metrics;

import java.util.Date;

public class EvaluationResult<T extends Comparable<T>> {
    private String termName;

    private Statement conditionStatement;
    private T value;
    private T measurementResultValue;
    private Date measurementTime;
    private boolean comparisonResult;

    private boolean error;
    private String errorMessage;

    EvaluationResult() {
        measurementTime = new Date();
    }

    public String getTermName() {
        return termName;
    }

    public void setTermName(String termName) {
        this.termName = termName;
    }

    public Statement getConditionStatement() {
        return conditionStatement;
    }

    void setConditionStatement(Statement conditionStatement, T value) {
        this.conditionStatement = conditionStatement;
        this.value = value;
    }

    public T getMeasurementResultValue() {
        return measurementResultValue;
    }

    void setMeasurementResultValue(T measurementResultValue) {
        this.measurementResultValue = measurementResultValue;
        switch (conditionStatement) {
            case greater:
                comparisonResult = measurementResultValue.compareTo(value) > 0;
                break;
            case less:
                comparisonResult = measurementResultValue.compareTo(value) < 0;
                break;
            case greaterOrEqual:
                comparisonResult = measurementResultValue.compareTo(value) >= 0;
                break;
            case lessOrEqual:
                comparisonResult = measurementResultValue.compareTo(value) <= 0;
                break;
            case equal:
                comparisonResult = measurementResultValue.compareTo(value) == 0;
                break;
            default:
                comparisonResult = false;
        }
    }

    public Date getMeasurementTime() {
        return measurementTime;
    }

    public boolean isConditionMet() {
        return comparisonResult;
    }

    public boolean isError() {
        return error;
    }

    public void setError(boolean error) {
        this.error = error;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }
}
