/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.mcsla.core.metrics;

import eu.DECIDEh2020.appManager.models.AppDescription;
import eu.DECIDEh2020.appManager.models.ServiceObjective;
import eu.DECIDEh2020.appManager.models.Sla;

import java.util.*;
import java.util.stream.Collectors;

public class MetricsContext {

    private AppDescription appDescription;

    private Map<String, Map<String, EvaluationResult>> store = new HashMap<>();

    static public MetricsContext create(AppDescription appDescription) {
        if (appDescription == null) {
            throw new IllegalArgumentException("appDescription has to be non null");
        }
        if (appDescription.getMcsla() == null) {
            throw new IllegalStateException("No metrics found");
        }
        return new MetricsContext(appDescription);
    }

    static public <T, V> T aggregate(List<V> values, Predefined predefined) {
        PredefinedExpression<T, V> expression = Expressions.create(predefined);
        return expression.calculate(values, Collections.emptyList());
    }

    private MetricsContext(AppDescription appDescription) {
        this.appDescription = appDescription;
    }

    public Map<String, ServiceObjectiveMetrics> getCsMetrics(String csId) {
        Sla sla = appDescription.getMcsla().getCsSlas().get(csId);
        Map<String, ServiceObjectiveMetrics> map = new HashMap<>();
        for (ServiceObjective objective : sla.getObjectives()) {
            map.put(objective.getTermName(), new ServiceObjectiveMetrics(this, csId, objective));
        }
        return map;
    }

    public Map<String, ServiceObjectiveMetrics> getAppMetrics() {
        Sla sla = appDescription.getMcsla().getSla();
        Map<String, ServiceObjectiveMetrics> map = new HashMap<>();
        for (ServiceObjective objective : sla.getObjectives()) {
            map.put(objective.getTermName(), new ServiceObjectiveMetrics(this, objective));
        }
        return map;
    }

    public <T, V> T aggregate(Predefined predefined, String termName) {
        PredefinedExpression<T, V> expression = Expressions.create(predefined);
        List<String> values = new ArrayList<>();
        Map<String, Sla> csSlas = appDescription.getMcsla().getCsSlas();
        csSlas.values().forEach(sla -> sla.getObjectives().stream().filter(o -> o.getTermName().equals(termName)).map(ServiceObjective::getValue).collect(Collectors.toCollection(() -> values)));
        return expression.calculateFromStrings(values, Collections.emptyList());
    }

    <T extends Comparable<T>> void store(String csId, EvaluationResult<T> result) {
        store.computeIfAbsent(csId, k -> new HashMap<>()).put(result.getTermName(), result);
    }

    List<EvaluationResult> restore(String termName) {
        return store.values().stream().filter(m -> m.containsKey(termName)).map(m -> m.get(termName)).collect(Collectors.toList());
    }

}
