/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.mcsla.service.repositories;

import io.vertx.codegen.annotations.Fluent;
import io.vertx.codegen.annotations.ProxyGen;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;
import io.vertx.core.Vertx;
import io.vertx.core.buffer.Buffer;
import io.vertx.core.json.JsonObject;
import io.vertx.ext.web.client.HttpRequest;

import java.nio.file.Path;
import java.util.List;

@ProxyGen
public interface RepositoriesService {

    static RepositoriesService create(Path base, HttpRequest<Buffer> acsmiRequest, Handler<AsyncResult<RepositoriesService>> readyHandler) {
        return new RepositoriesServiceImpl(base, acsmiRequest, readyHandler);
    }

    static RepositoriesService createProxy(Vertx vertx, String address) {
        return new RepositoriesServiceVertxEBProxy(vertx, address);
    }

    @Fluent
    RepositoriesService isLocal(String appName, Handler<AsyncResult<Boolean>> handler);

    @Fluent
    RepositoriesService initRepository(String ref, String token, String username, String password, Handler<AsyncResult<JsonObject>> handler);

    @Fluent
    RepositoriesService getApplication(String AppName, Handler<AsyncResult<JsonObject>> handler);

    @Fluent
    RepositoriesService resetApplication(String AppName, Handler<AsyncResult<JsonObject>> handler);

    @Fluent
    RepositoriesService updateMcsla(String appName, JsonObject mcsla, Handler<AsyncResult<JsonObject>> handler);

    @Fluent
    RepositoriesService aggregateServiceObjectives(String name, String termName, String predefined, Handler<AsyncResult<JsonObject>> handler);

}
