/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.mcsla.service.repositories;

import io.vertx.core.AbstractVerticle;
import io.vertx.core.Future;
import io.vertx.core.buffer.Buffer;
import io.vertx.ext.web.client.HttpRequest;
import io.vertx.ext.web.client.WebClient;
import io.vertx.serviceproxy.ServiceBinder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.nio.file.*;

public class RepositoriesVerticle extends AbstractVerticle {

    private Logger log = LoggerFactory.getLogger(getClass());

    @Override
    public void start(Future<Void> startFuture) {

        String baseDir = config().getString("DECIDE_REPOS_BASE_DIR");
        String acsmiUri = config().getString("DECIDE_ACSMI_DISCOVERY_SERVICE_URI");

        Path base = null;
        try {
            base = baseDir != null ? Paths.get(baseDir) : Files.createTempDirectory("mcsla_");
        } catch (IOException e) {
            log.error("creating temp base directory", e);
        }

        HttpRequest<Buffer> acsmiRequest = null;
        if (acsmiUri != null && !acsmiUri.isEmpty()) {
            WebClient acsmiClient = WebClient.create(vertx);
            acsmiRequest = acsmiClient.getAbs(acsmiUri + "/acsmiservices/api/services/nfr");
        }

        RepositoriesService.create(base, acsmiRequest, ready -> {
            if (ready.succeeded()) {
                new ServiceBinder(vertx).setAddress("decide.mcsla.service.repositories.queue").register(RepositoriesService.class, ready.result());
                log.debug("repositories service bound");
                startFuture.complete();
            } else {
                startFuture.fail(ready.cause());
            }
        });
        log.debug("repositories verticle started");
    }

}
