/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
import React, { Component } from 'react';
import { connect } from 'react-redux';
import { withRouter } from 'react-router-dom'
import { Switch, Route } from 'react-router';
import './App.css';
import 'typeface-roboto';
import MuiThemeProvider from '@material-ui/core/styles/MuiThemeProvider';
import {createMuiTheme, withStyles} from '@material-ui/core/styles';
import deepOrange500 from '@material-ui/core/colors';
import CircularProgress from '@material-ui/core/CircularProgress'
import CssBaseline from '@material-ui/core/CssBaseline'
import DecideAppView from './DecideAppView'
import AppHeader from './AppHeader'
import McslaView from './McslaView'
import RawView from './RawView'
import Typography from '@material-ui/core/Typography';

const muiTheme = createMuiTheme({
    palette: {
        accent1Color: deepOrange500
    }
});

const styles = theme => ({
    root: {
        flexGrow: 1,
        zIndex: 1,
        overflow: 'hidden',
        position: 'relative',
        display: 'flex'
    },
    center: {
        position: 'absolute',
        margin: 'auto',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        width: '200px',
        height: '200px',
        verticalAlign: 'middle',
        textAlign: 'center'
    },
    flex: {
        flex: 1,
    },
    content: {
        flexGrow: 1,
        backgroundColor: theme.palette.background.default,
        padding: theme.spacing.unit * 3,
        marginTop: 60
    },
    iframeContent: {
        flexGrow: 1,
        backgroundColor: theme.palette.background.default,
        padding: theme.spacing.unit * 3
    }
});

class App extends Component {

    render() {
        const { classes } = this.props;

        return (
            <MuiThemeProvider theme={muiTheme}>
                <CssBaseline/>
                <Switch>
                    <Route exact path="/iframe" render={() => 
                        <div className={classes.root}>
                            <main className={classes.iframeContent}>
                                {this.props.contentAvailable ?
                                    <McslaView/>
                                    :
                                    <div className={classes.center}> {this.props.busy ? <CircularProgress/> : <Typography color="textSecondary" variant="subheading">{this.props.error}</Typography>}</div>
                                }
                            </main>
                        </div>
                    } />
                    <Route render={() => 
                        <div className={classes.root}>
                            <AppHeader serviceUri={this.props.serviceUri}/>
                            <main className={classes.content}>
                                {this.props.contentAvailable ?
                                    <Switch>
                                        <Route exact path="/" component={DecideAppView} />
                                        <Route path="/mcsla" component={McslaView} />
                                        <Route path="/raw" component={RawView} />
                                    </Switch>
                                    :
                                    <div className={classes.center}> {this.props.busy ? <CircularProgress/> : <Typography color="textSecondary" variant="subheading">{this.props.error}</Typography>}</div>
                                }
                            </main>
                        </div>
                    } />
                </Switch>
            </MuiThemeProvider>
        );
    }
}

const mapStateToProps = state => {
    return {
        contentAvailable: Object.keys(state.decideApp).length > 0 && state.decideApp.constructor === Object,
        busy: state.app.isFetching,
        error: state.app.error.message,
        serviceUri: state.app.serviceUri
    }
};

export default withRouter(connect(mapStateToProps, null)(withStyles(styles, { withTheme: true })(App)));
