import React, { Component } from 'react'

import AppBar from '@material-ui/core/AppBar';
import RepoForm from './RepoForm';
import Toolbar from '@material-ui/core/Toolbar'
import Typography from '@material-ui/core/Typography'
import { withStyles } from "@material-ui/core/styles/index";
import Drawer from '@material-ui/core/Drawer';
import IconButton from '@material-ui/core/IconButton';
import MenuIcon from '@material-ui/icons/Menu';
import ChevronRightIcon from '@material-ui/icons/ChevronRight';
import ChevronLeftIcon from '@material-ui/icons/ChevronLeft';
import AppsIcon from '@material-ui/icons/Apps';
import CodeIcon from '@material-ui/icons/Code';
import CloudIcon from '@material-ui/icons/Cloud';
import Divider from '@material-ui/core/Divider';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import classNames from 'classnames';
import { ListItemIcon, ListItemText } from '@material-ui/core';
import { Link } from 'react-router-dom';
import { version } from '../../package.json'

const drawerWidth = 240;

const styles = theme => ({
    appBar: {
        zIndex: theme.zIndex.drawer + 1,
        transition: theme.transitions.create(['width', 'margin'], {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.leavingScreen,
        }),
    },
    appBarShift: {
        marginLeft: drawerWidth,
        width: `calc(100% - ${drawerWidth}px)`,
        transition: theme.transitions.create(['width', 'margin'], {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.enteringScreen,
        }),
    },
    menuButton: {
        marginLeft: -12,
        marginRight: 36
    },
    hide: {
        display: 'none',
    },
    toolbar: {
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'flex-end',
        padding: '0 8px',
        ...theme.mixins.toolbar
    },
    drawerPaper: {
        position: 'relative',
        whiteSpace: 'nowrap',
        width: drawerWidth,
        height: '100vh',
        transition: theme.transitions.create('width', {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.enteringScreen,
        }),
    },
    drawerPaperClose: {
        overflowX: 'hidden',
        transition: theme.transitions.create('width', {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.leavingScreen,
        }),
        width: theme.spacing.unit * 7,
        [theme.breakpoints.up('sm')]: {
            width: theme.spacing.unit * 9,
        },
    },
    grow: {
        flexGrow: 1,
    }
});

class AppHeader extends Component {
    state = {
        open: false,
    };

    handleDrawerOpen = () => {
        this.setState({ open: true });
    };

    handleDrawerClose = () => {
        this.setState({ open: false });
    };

    render() {
        const { classes, theme, serviceUri } = this.props;

        return (
            <div>
                <AppBar position="absolute" className={classNames(classes.appBar, this.state.open && classes.appBarShift)}>
                    <Toolbar>
                        <IconButton color="inherit" aria-label="open drawer" onClick={this.handleDrawerOpen}
                            className={classNames(classes.menuButton, this.state.open && classes.hide)}>
                            <MenuIcon />
                        </IconButton>
                        <Typography variant="title" color="inherit" noWrap className={classes.grow}>DECIDE MCSLA Editor</Typography>
                        <RepoForm />
                    </Toolbar>
                </AppBar>
                <Drawer variant="permanent" open={this.state.open} classes={{ paper: classNames(classes.drawerPaper, !this.state.open && classes.drawerPaperClose) }}>
                    <div className={classes.toolbar}>
                        <Typography variant="caption" align="left" noWrap>{'v' + version + ' (' + serviceUri + ')'}</Typography>
                        <IconButton onClick={this.handleDrawerClose}>
                            {theme.direction === 'rtl' ? <ChevronRightIcon /> : <ChevronLeftIcon />}
                        </IconButton>
                    </div>
                    <Divider />
                    <List>
                        <Link to="/">
                            <ListItem button>
                                    <ListItemIcon><AppsIcon/></ListItemIcon>
                                    <ListItemText>DECIDE Application</ListItemText>
                            </ListItem>
                        </Link>
                        <Link to="/mcsla">
                            <ListItem button>
                                <ListItemIcon><CloudIcon/></ListItemIcon>
                                <ListItemText>Multi-Cloud SLA</ListItemText>
                            </ListItem>
                        </Link>
                        <Link to="/raw">
                            <ListItem button>
                                <ListItemIcon><CodeIcon/></ListItemIcon>
                                <ListItemText>Raw Structure</ListItemText>
                            </ListItem>
                        </Link>
                    </List>
                </Drawer>
            </div>
        )
    }
}

export default withStyles(styles, { withTheme: true })(AppHeader)