import React, { Component } from "react";
import { connect } from 'react-redux';
import { Typography, Chip, TextField, InputAdornment, IconButton, withStyles } from "@material-ui/core";
import AddIcon from '@material-ui/icons/Add';
import { addCoveredService, deleteCoveredService } from "../actions/editmcsla";

const styles = theme => ({
    chip: {
        margin: theme.spacing.unit
    }
});

class CoveredServices extends Component {

    state = {
        newService: ""
    }

    handleChangeService(event) {
        this.setState({newService: event.target.value});
    }

    handleAddService() {
        if (this.state.newService) {
            this.props.addService(this.state.newService);
            this.setState({newService: ""});
        }
    }

    handleDeleteService(service) {
        this.props.deleteService(service);
    }

    render() {
        const { classes } = this.props;

        return (
            <div>
                {!this.props.readOnly ? <TextField margin="normal" value={this.state.newService} placeholder="Add covered service" onChange={event => this.handleChangeService(event)} InputProps={{endAdornment: <InputAdornment position="end" ><IconButton onClick={() => this.handleAddService()}><AddIcon/></IconButton></InputAdornment>}}/> : null}
                <Typography component="div" color="textSecondary" align="left">
                    Covered services:
                    {this.props.coveredServices && this.props.coveredServices.length > 0 ? Object.values(this.props.coveredServices).map(service => {
                    return this.props.readOnly ? 
                        (
                            <Chip key={service} className={classes.chip} label={service} />
                        )
                        :
                        (
                            <Chip key={service} className={classes.chip} label={service} onDelete={() => this.handleDeleteService(service)} />
                        )
                    })
                    :
                    ' All'
                    }
                </Typography>
            </div>
        )        
    }
}

const mapDispatchToProps = dispatch => {
    return {
        addService: service => dispatch(addCoveredService(service)),
        deleteService: service => dispatch(deleteCoveredService(service))
    }
}

export default connect(null, mapDispatchToProps)(withStyles(styles, { withTheme: true })(CoveredServices))
