import React, { Component } from 'react';
import { connect } from 'react-redux';
import { withRouter } from 'react-router-dom'

import List from '@material-ui/core/List';
import ListSubheader from '@material-ui/core/ListSubheader';
import ListItem from '@material-ui/core/ListItem';
import ListItemText from '@material-ui/core/ListItemText';
import Grid from '@material-ui/core/Grid';
import Typography from '@material-ui/core/Typography';
import { withStyles } from "@material-ui/core/styles/index";
import DecideAppSheet from './DecideAppSheet';
import Avatar from '@material-ui/core/Avatar';
import Divider from '@material-ui/core/Divider';
import NfrListItem from './NfrListItem';

const styles = {
    flex: {
        flex: 1
    }
};

class DecideAppView extends Component {
    render() {
        const { decideApp } = this.props

        return (
            <Grid container spacing={24}>
                <Grid item md={12}>
                    <DecideAppSheet />
                    <Divider />
                </Grid>
                <Grid item md={6}>
                    <List subheader={<ListSubheader><Typography color="textSecondary" variant="headline">NFRs</Typography></ListSubheader>}>
                        {decideApp.nfrs ? Object.values(decideApp.nfrs).map(nfr => {
                            return (
                                <NfrListItem key={decideApp.nfrs.indexOf(nfr)} nfr={nfr} /> 
                            )
                        })
                        :
                        <Typography color="textSecondary" variant="subheading" paragraph={true}>No NFRs specified</Typography> 
                        }
                    </List>
                </Grid>
                <Grid item md={6}>
                    <List subheader={<ListSubheader><Typography color="textSecondary" variant="headline">Microservices</Typography></ListSubheader>}>
                        {decideApp.microservices ? Object.values(decideApp.microservices).map(microservice => {
                                return (
                                    <ListItem key={microservice.id}>
                                        <Avatar color="orange">M</Avatar>
                                        <ListItemText primary={microservice.name} secondary={microservice.type} />
                                    </ListItem>
                                )
                            })
                            :
                            <Typography color="textSecondary" variant="subheading" paragraph={true}>No microservices specified</Typography>
                        }
                    </List>
                </Grid>
            </Grid>
        )
    }
}

const mapStateToProps = state => {
    return {
        decideApp: state.decideApp || 'No content available',
    }
};

export default withRouter(connect(mapStateToProps, null)(withStyles(styles, {withTheme: true})(DecideAppView)))
