import React, { Component } from "react";
import { withStyles } from "@material-ui/core/styles/index";
import ListItem from '@material-ui/core/ListItem';
import ListItemText from '@material-ui/core/ListItemText';
import Avatar from '@material-ui/core/Avatar';
import UpdateIcon from '@material-ui/icons/Update';
import NetworkCheckIcon from '@material-ui/icons/NetworkCheck';
import LocationIcon from '@material-ui/icons/LocationOn';
import EuroSymbolIcon from '@material-ui/icons/EuroSymbol';
import BlurOnIcon from '@material-ui/icons/BlurOn';
import QuestioAnswerIcon from '@material-ui/icons/QuestionAnswer'

const styles = {
    flex: {
        flex: 1
    }
};

const units = {
    "percentage": "%",
    "millisecond": "ms",
    "euro": "€",
    "request/second": "req/s"
}

class NfrListItem extends Component {
    render() {
        const { nfr } = this.props;
        let icon;
        let secondary;

        switch (nfr.type) {
        case "Availability":
            icon = <UpdateIcon/>;
            secondary = nfr.value ? nfr.value + units[nfr.unit] : '';
            break;
        case "Performance":
            icon = <NetworkCheckIcon/>;
            secondary = nfr.value ? nfr.value + units[nfr.unit] : '';
            break;
        case "Scalability":
            icon = <BlurOnIcon/>;
            secondary = nfr.value ? nfr.value : '';
            break;
        case "Location":
            icon = <LocationIcon/>;
            secondary = nfr.value ? nfr.value : '';
            break;
        case "Cost":
            icon = <EuroSymbolIcon/>;
            secondary = nfr.value ? nfr.value + units[nfr.unit] : '';
            break;
        default:
            icon = <QuestioAnswerIcon/>;
            secondary = "Don't know";
            break;
        }

        return (
            <ListItem key={this.props.key}>
                <Avatar>{icon}</Avatar>
                <ListItemText primary={nfr.type + ' - ' + nfr.abstractValue} secondary={secondary}/>
            </ListItem>
        )
    } 
}

export default withStyles(styles, {withTheme: true})(NfrListItem)
