import React, { Component } from 'react'
import { connect } from 'react-redux'

import { withStyles } from '@material-ui/core/styles'
import TextField from '@material-ui/core/TextField'
import Button from '@material-ui/core/Button'
import Drawer from '@material-ui/core/Drawer'
import AppBar from '@material-ui/core/AppBar'
import Toolbar from '@material-ui/core/Toolbar'
import IconButton from '@material-ui/core/IconButton'
import CloseIcon from '@material-ui/icons/Close'
import Grid from '@material-ui/core/Grid'
import Typography from '@material-ui/core/Typography'
import { useRepository } from '../actions/repository'
import { fetchDecideAppRequest } from "../actions/mcsla";
import SvgIcon from '@material-ui/core/SvgIcon'

const styles = {
    flex: {
        flex: 1
    }
};

class RepoForm extends Component {

    state = {
        open: false
    } 

    handleToggle = () => this.setState({open: !this.state.open});

    handleUriChange = event => this.props.updateRepository(event.target.value, this.props.token, this.props.username, this.props.password);

    handleTokenChange = event => this.props.updateRepository(this.props.uri, event.target.value, this.props.username, this.props.password);

    handleUsernameChange = event => this.props.updateRepository(this.props.uri, this.props.token, event.target.value, this.props.password);

    handlePasswordChange = event => this.props.updateRepository(this.props.uri, this.props.token, this.props.username, event.target.value);

    handleUse = () => {
        this.props.useRepository()
        this.setState({open: false})
    };

    render() {
        const { classes } = this.props;

        return (
            <div>
                <IconButton color="inherit" onClick={this.handleToggle}>
                    <SvgIcon>
                        <path d="M2.6,10.59L8.38,4.8L10.07,6.5C9.83,7.35 10.22,8.28 11,8.73V14.27C10.4,14.61 10,15.26 10,16A2,2 0 0,0 12,18A2,2 0 0,0 14,16C14,15.26 13.6,14.61 13,14.27V9.41L15.07,11.5C15,11.65 15,11.82 15,12A2,2 0 0,0 17,14A2,2 0 0,0 19,12A2,2 0 0,0 17,10C16.82,10 16.65,10 16.5,10.07L13.93,7.5C14.19,6.57 13.71,5.55 12.78,5.16C12.35,5 11.9,4.96 11.5,5.07L9.8,3.38L10.59,2.6C11.37,1.81 12.63,1.81 13.41,2.6L21.4,10.59C22.19,11.37 22.19,12.63 21.4,13.41L13.41,21.4C12.63,22.19 11.37,22.19 10.59,21.4L2.6,13.41C1.81,12.63 1.81,11.37 2.6,10.59Z" />
                    </SvgIcon>
                </IconButton>
                <Drawer width={400} anchor="right" open={this.state.open} >
                    <AppBar position="static">
                        <Toolbar>
                            <Typography className={classes.flex} />
                            <IconButton color="inherit" onClick={() => this.handleToggle()}><CloseIcon /></IconButton>
                        </Toolbar>
                    </AppBar>

                    <Grid container spacing={24} style={{padding: 24}}>
                        <Grid item md={12}>
                            <TextField fullWidth label="URI" value={this.props.uri} autoFocus={true} onChange={event => this.handleUriChange(event)} margin="normal" />
                            <TextField fullWidth label="Access token" value={this.props.token} onChange={event => this.handleTokenChange(event)} margin="normal" />
                            <TextField fullWidth label="Username" value={this.props.username} onChange={event => this.handleUsernameChange(event)} margin="normal"/>
                            <TextField fullWidth label="Password" type="password" value={this.props.password} onChange={event => this.handlePasswordChange(event)} margin="normal"/>
                        </Grid>
                        <Grid item md={12}>
                            <Button variant="raised" color="primary" onClick={() => this.handleUse()}>use</Button>
                        </Grid>
                    </Grid>
                </Drawer>
            </div>
        )
    }
}

const mapStateToProps = state => {
    return {
        uri: state.repository.uri || "",
        token: state.repository.token || "",
        username: state.repository.username || "",
        password: state.repository.password || ""
    }
};

const mapDispatchToProps = dispatch => {
    return {
        updateRepository: (uri, token, username, password) => dispatch(useRepository(uri, token, username, password)), 
        useRepository: () => dispatch(fetchDecideAppRequest())
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(withStyles(styles, { withTheme: true })(RepoForm))
